@@ -3,15 +3,15 @@
 set -o errexit
 set -x
 
-CFLAGS=""
+COMMON_CFLAGS=""
 OVN_CFLAGS=""
-SPARSE_FLAGS=""
 EXTRA_OPTS="--enable-Werror"
 
 function configure_ovs()
 {
     pushd ovs
-    ./boot.sh && ./configure $* || { cat config.log; exit 1; }
+    ./boot.sh && ./configure CFLAGS="${COMMON_CFLAGS}" $* || \
+    { cat config.log; exit 1; }
     make -j4 || { cat config.log; exit 1; }
     popd
 }
@@ -19,40 +19,43 @@ function configure_ovs()
 function configure_ovn()
 {
     configure_ovs $*
-
-    export OVS_CFLAGS="${OVS_CFLAGS} ${OVN_CFLAGS}"
-    ./boot.sh && ./configure $* || \
+    ./boot.sh && ./configure CFLAGS="${COMMON_CFLAGS} ${OVN_CFLAGS}" $* || \
     { cat config.log; exit 1; }
 }
 
 save_OPTS="${OPTS} $*"
 OPTS="${EXTRA_OPTS} ${save_OPTS}"
 
-# If AddressSanitizer is requested, enable it, but only for OVN, not for OVS.
-# However, disable some optimizations for OVS, to make AddressSanitizer
-# reports user friendly.
-if [ "$ASAN" ]; then
-    CFLAGS="-fno-omit-frame-pointer -fno-common"
-    OVN_CFLAGS="-fsanitize=address"
+# If AddressSanitizer and UndefinedBehaviorSanitizer are requested, enable them,
+# but only for OVN, not for OVS.  However, disable some optimizations for
+# OVS, to make sanitizer reports user friendly.
+if [ "$SANITIZERS" ]; then
+    # Use the default options configured in tests/atlocal.in, in UBSAN_OPTIONS.
+    COMMON_CFLAGS="${COMMON_CFLAGS} -O1 -fno-omit-frame-pointer -fno-common -g"
+    OVN_CFLAGS="${OVN_CFLAGS} -fsanitize=address,undefined"
 fi
 
 if [ "$CC" = "clang" ]; then
-    export OVS_CFLAGS="$CFLAGS -Wno-error=unused-command-line-argument"
+    COMMON_CFLAGS="${COMMON_CFLAGS} -Wno-error=unused-command-line-argument"
 elif [ "$M32" ]; then
     # Not using sparse for 32bit builds on 64bit machine.
-    # Adding m32 flag directly to CC to avoid any posiible issues with API/ABI
+    # Adding m32 flag directly to CC to avoid any possible issues with API/ABI
     # difference on 'configure' and 'make' stages.
     export CC="$CC -m32"
 else
     OPTS="$OPTS --enable-sparse"
-    export OVS_CFLAGS="$CFLAGS $SPARSE_FLAGS"
 fi
 
 if [ "$TESTSUITE" ]; then
+    TESTSUITEFLAGS=""
+    if [[ ! -z $TESTSUITE_KW ]]; then
+        TESTSUITEFLAGS="-k $TESTSUITE_KW"
+    fi
+
     if [ "$TESTSUITE" = "system-test" ]; then
         configure_ovn $OPTS
         make -j4 || { cat config.log; exit 1; }
-        if ! sudo make -j4 check-kernel RECHECK=yes; then
+        if ! sudo make -j4 check-kernel TESTSUITEFLAGS="$TESTSUITEFLAGS" RECHECK=yes; then
             # system-kmod-testsuite.log is necessary for debugging.
             cat tests/system-kmod-testsuite.log
             exit 1
@@ -63,7 +66,9 @@ if [ "$TESTSUITE" ]; then
         configure_ovn
 
         export DISTCHECK_CONFIGURE_FLAGS="$OPTS"
-        if ! make distcheck -j4 TESTSUITEFLAGS="-j4" RECHECK=yes; then
+        if ! make distcheck CFLAGS="${COMMON_CFLAGS} ${OVN_CFLAGS}" -j4 \
+            TESTSUITEFLAGS="$TESTSUITEFLAGS -j4" RECHECK=yes
+        then
             # testsuite.log is necessary for debugging.
             cat */_build/sub/tests/testsuite.log
             exit 1
