@@ -45,10 +45,4 @@ const struct ovsrec_bridge *get_bridge(const struct ovsrec_bridge_table *,
 
 uint32_t get_tunnel_type(const char *name);
 
-struct pb_ld_binding {
-    const struct sbrec_port_binding *pb;
-    const struct local_datapath *ld;
-    struct hmap_node hmap_node;
-};
-
 #endif /* controller/ovn-controller.h */
