@@ -367,6 +367,8 @@ bool expr_relop_from_token(enum lex_type type, enum expr_relop *relop);
 struct expr {
     struct ovs_list node;       /* In parent EXPR_T_AND or EXPR_T_OR if any. */
     enum expr_type type;        /* Expression type. */
+    char *as_name;              /* Address set name. Null if it is not an
+                                   address set. */
 
     union {
         /* EXPR_T_CMP.
@@ -417,13 +419,13 @@ size_t expr_size(const struct expr *);
 struct expr *expr_parse(struct lexer *, const struct shash *symtab,
                         const struct shash *addr_sets,
                         const struct shash *port_groups,
-                        struct sset *addr_sets_ref,
+                        struct shash *addr_sets_ref,
                         struct sset *port_groups_ref,
                         int64_t dp_id);
 struct expr *expr_parse_string(const char *, const struct shash *symtab,
                                const struct shash *addr_sets,
                                const struct shash *port_groups,
-                               struct sset *addr_sets_ref,
+                               struct shash *addr_sets_ref,
                                struct sset *port_groups_ref,
                                int64_t dp_id,
                                char **errorp);
@@ -469,6 +471,11 @@ struct expr_match {
     struct match match;
     struct cls_conjunction *conjunctions;
     size_t n, allocated;
+
+    /* Tracked address set information. */
+    char *as_name;
+    struct in6_addr as_ip;
+    struct in6_addr as_mask;
 };
 
 uint32_t expr_to_matches(const struct expr *,
@@ -477,6 +484,7 @@ uint32_t expr_to_matches(const struct expr *,
                                              unsigned int *portp),
                          const void *aux,
                          struct hmap *matches);
+void expr_match_destroy(struct expr_match *);
 void expr_matches_destroy(struct hmap *matches);
 size_t expr_matches_prepare(struct hmap *matches, uint32_t conj_id_ofs);
 void expr_matches_print(const struct hmap *matches, FILE *);
@@ -526,11 +534,20 @@ struct expr_constant_set {
     size_t n_values;              /* Number of constants. */
     enum expr_constant_type type; /* Type of the constants. */
     bool in_curlies;              /* Whether the constants were in {}. */
+    char *as_name;                /* Name of an address set. It is NULL if not
+                                     an address set. */
 };
 
 bool expr_constant_set_parse(struct lexer *, struct expr_constant_set *);
 void expr_constant_set_format(const struct expr_constant_set *, struct ds *);
 void expr_constant_set_destroy(struct expr_constant_set *cs);
+struct expr_constant_set * expr_constant_set_create_integers(
+                                const char *const *values, size_t n_values);
+void expr_constant_set_integers_diff(
+                                struct expr_constant_set *old,
+                                struct expr_constant_set *new,
+                                struct expr_constant_set **p_diff_added,
+                                struct expr_constant_set **p_diff_deleted);
 
 
 /* Constant sets.
@@ -544,7 +561,8 @@ void expr_constant_set_destroy(struct expr_constant_set *cs);
  * integer/masked-integer values. The values that don't qualify
  * are ignored.
  */
-
+void expr_const_sets_add(struct shash *const_sets, const char *name,
+                         struct expr_constant_set *);
 void expr_const_sets_add_integers(struct shash *const_sets, const char *name,
                                   const char * const *values, size_t n_values);
 void expr_const_sets_add_strings(struct shash *const_sets, const char *name,
