@@ -145,6 +145,14 @@ struct gen_opts_map {
 #define DHCP_OPT_TCP_KEEPALIVE_INTERVAL \
     DHCP_OPTION("tcp_keepalive_interval", 38, "uint32")
 
+/* Use unused 253 option for DHCP next-server DHCP option.
+ * This option is used for setting the "Next server IP address"
+ * field in the DHCP header.
+ */
+#define DHCP_OPT_NEXT_SERVER_CODE 253
+#define DHCP_OPT_NEXT_SERVER \
+    DHCP_OPTION("next_server", DHCP_OPT_NEXT_SERVER_CODE, "ipv4")
+
 static inline uint32_t
 gen_opt_hash(char *opt_name)
 {
@@ -220,12 +228,6 @@ struct dhcp_opt_header {
 #define DHCP_OPT_PAYLOAD(hdr) \
     (void *)((char *)hdr + sizeof(struct dhcp_opt_header))
 
-/* Used in the OpenFlow PACKET_IN userdata */
-struct dhcp_opt6_header {
-    ovs_be16 opt_code;
-    ovs_be16 size;
-};
-
 /* These are not defined in ovs/lib/dhcp.h, hence defining here. */
 #define OVN_DHCP_MSG_DECLINE        4
 #define OVN_DHCP_MSG_RELEASE        7
